@@ -4,7 +4,11 @@ Reusable methods throughout DYC
 import os
 import yaml
 import string
-from exceptions import DYCConfigurationSetup
+INDENT_OPTIONS = {
+    'tab': '\t',
+    '2 spaces': '  ',
+    'False': '',
+}
 
 
 def get_leading_whitespace(s): 
@@ -25,21 +29,6 @@ def get_leading_whitespace(s):
             break 
     return ''.join(accumulator) 
 
-def read_config(path):
-    """
-    None
-    Parameters
-    ----------
-    None path: None
-    """
-    try:
-        with open(path, 'r') as config:
-            try:
-                yield yaml.load(config)
-            except yaml.YAMLError as exc:
-                print(exc)
-    except IOError as io_err:
-        print('Configuration File missing, using default')
 
 def read_yaml(path):
     """
@@ -51,25 +40,18 @@ def read_yaml(path):
     try:
         with open(path, 'r') as config:
             try:
-                return yaml.load(config)
+                return yaml.safe_load(config)
             except yaml.YAMLError as exc:
                 return None
     except IOError as io_err:
         return None
 
+
 class BlankFormatter(string.Formatter):
     def __init__(self, default=''):
         self.default=default
 
     def get_value(self, key, args, kwds):
-        """
-        None
-        Parameters
-        ----------
-        None key: None
-        None args: None
-        None kwds: None
-        """
         if isinstance(key, str):
             return kwds.get(key, self.default)
         else:
@@ -78,20 +60,16 @@ class BlankFormatter(string.Formatter):
 
 def get_indent(space):
     """
-    Translater of the indent config param to real spaces or
+    Translator of the indent config param to real spaces or
     tabs
     Parameters
     ----------
     str space: The value of `indent` in a config file
     """
-    if space == 'tab':
-        return '\t'
-    elif space == '2 spaces':
-        return '  '
-    elif space == False:
-        return ''
-    else:
+    value = INDENT_OPTIONS.get(str(space))
+    if value is None:
         return '    '
+    return value
 
 def get_extension(filename):
     """
@@ -100,7 +78,10 @@ def get_extension(filename):
     ----------
     str filename: the filename to extract extension from
     """
-    return os.path.splitext(filename)[1].replace('.', '')
+    try:
+        return os.path.splitext(filename)[1].replace('.', '')
+    except AttributeError:
+        return ''
 
 
 def all_files_generator(extensions=[]):
